Stan Math Library: stan/math/prim/arr/meta/get.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
get.hpp File Reference
`#include <cstdlib>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan

## Functions
template<typename T >
T | stan::get (const std::vector< T > &x, size_t n)

[ Stan Home Page ] © 2011–2016, Stan Development Team.